# Type stubs for google-auth-stubs
[![PyPI version](https://badge.fury.io/py/google-auth-stubs.svg)](https://badge.fury.io/py/google-auth-stubs)

This package provides type stubs for the [google-auth](https://pypi.org/project/google-auth/) package.

**This is in no way affiliated with Google.**

The stubs were created automatically by [stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html).

## Installation
```shell script
$ pip install google-auth-stubs
```
